=========
More Help
=========

If you plan to do serious development with Trame and its ecosystem, we strongly recommend you use the following sources as references:

- `Trame API <https://trame.readthedocs.io/en/latest/index.html>`_: This will provide you with detailed information on all widgets and utilities provided by Trame.
- `Trame Discussion Board <https://github.com/Kitware/trame/discussions>`_: If you notice any issues or have any questions about Trame itself, this is the best place to ask. The developers of Trame are very active on this board.
- `Vuetify Component Docs <https://vuetifyjs.com/en/components/all/>`_: Each of the components described here is available via a Trame widget. This documentation is great for understanding how each of the components works and where its appropriate to be used.
- `MDN Web Docs <https://developer.mozilla.org/en-US/>`_: Even though you'll be doing most of your development work in Python, Trame ultimately produces HTML, CSS, and JavaScript. The MDN Web Docs are the best reference for these technologies and should be your starting point if you have questions about how something is working in your browser.
